##  Step 1: Create a Manifest File
To start your microservice discovery, first generate a valid manifest file (leanix.yaml) in your repository. Within this file, specify the details of your microservice.
To view the manifest file and schema, refer to [Manifest File and Schema](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema?locale=en-US&state=PRODUCTION&version=CLOUD "Manifest file for microservice discovery and the manifest schema.").
**Note**
A manifest file describes only one microservice. Depending on your repository setup, you may need to store one or more manifest files in the repository. For more details, see [Storing Manifest Files in Repositories](https://help.sap.com/docs/leanix/ea/manifest-file-and-schema?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b12037a44101489cfb50ab1e9e63c__storing_manifest_files_in_repositories).
